ith_stat returns the type of stat used by the ith layer.
See also
Other functions for checking stats:
get_stats(),
ith_stat_is(),
uses_stats()
ith_stat returns the type of stat used by the ith layer.
Other functions for checking stats:
get_stats(),
ith_stat_is(),
uses_stats()