ith_stat_is checks whether the ith layer uses the prescribed type of stat
See also
Other functions for checking stats:
get_stats(),
ith_stat(),
uses_stats()
ith_stat_is checks whether the ith layer uses the prescribed type of stat
Other functions for checking stats:
get_stats(),
ith_stat(),
uses_stats()